changelog
=========

Basic linting of changelog fragments with `antsibull-changelog lint <https://pypi.org/project/antsibull-changelog/>`_.

One or more of the following sections are required:

- major_changes
- minor_changes
- breaking_changes
- deprecated_features
- removed_features
- security_fixes
- bugfixes
- known_issues

New modules and plugins must not be included in changelog fragments.

See :ref:`collection_changelogs` for details.
